@@ -245,7 +245,7 @@ class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
                 user = {"name": os.getenv("TEST_USER")}
                 using_test_user = True
             req_data = tornado.escape.json_decode(self.request.body)
-            ref_data = tornado.escape.json_decode(self.request)
+            ref_data = self.request.headers.get("Referer")
             log_info_csv("GOT IT", course, section, assignment, str(ref_data))
             # in the future, assignment should be metadata in notebook
             if 'nb' in req_data:
